/*
**
**   This code is a part of the ETSI Technical Specification 06.77,
**   Digital cellular telecommunications system (Phase 2+);
**   Minimum Performance Requirements for Noise Suppresser Application to the AMR Speech Encoder
**
*/
/*
       =============================================================
       COPYRIGHT NOTE: This source code, and all of its derivations,
       is subject to the "ITU-T SOFTWARE TOOLS' GENERAL PUBLIC LICENSE". 
	   Please have it  read  in    the  distribution  disk,   or  in  
	   the  ITU-T Recommendation G.191 on "SOFTWARE TOOLS FOR SPEECH AND  
	   AUDIO CODING STANDARDS".
       =============================================================
*/



/*
**
**   OBJECTIVE MEASURES FOR CHARACTERISATION OF AMR/NS SOLUTIONS
**
**
**   MODULE:         DescDb.c, data structures for the characterisation
**                     of the speech sample database
**   ORIGINAL BY:    
**      Beghdad Ayad     Nokia Research Center    Finland
**      Erkki Paajanen   Nokia Research Center    Finland
**   DATE:           19/Jan/2001
**   RELEASE:        1.00
**   FUNCTIONS:      none
**   PROTOTYPES:     no functions
**   NOTES:          The data structures in this file need to be tailored to
**                   cover the speech database to be used in the subjective testing
**                   of the AMR/NS solution under study to enable the computation
**                   of the objective measures over the same material in car and
**                   street noise conditions. The example data structures provided
**                   the original version of this file describe the relevant
**                   conditions of the AMR/NS selection phase subjective tests.
**
**
**   MODIFICATION HISTORY:
**      15/Jun/00 v0.90 Release for inclusion in ETSI TS 06.77.   <erkki.paajanen@nokia.com>
**      19/Jan/01 v1.00 CR release: Inclusion of "ITU-T General Public License" terms.
**                                                                <erkki.paajanen@nokia.com>
**
**
*/


/*
** Copyright (c) 1999-2001 Nokia Corporation
*/


#include "main.h"


/***********************************************************************/
/*             Test conditions for the SNRI and NPLR measures          */
/***********************************************************************/

char *cond_name[] = {
   "Test Condition 1a:  CAR NOISE@6dB,     Level = -26dBov, AMR12.2",
   "Test Condition 1b:  CAR NOISE@6dB,     Level = -26dBov, AMR5.9",
   "Test Condition 2a:  CAR NOISE@12dB,    Level = -26dBov, AMR12.2",
   "Test Condition 2b:  CAR NOISE@12dB,    Level = -26dBov, AMR5.9",
   "Test Condition 3a:  STREET NOISE@9dB,  Level = -26dBov, AMR12.2",
   "Test Condition 3b:  STREET NOISE@9dB,  Level = -26dBov, AMR5.9",
   "Test Condition 4a:  STREET NOISE@15dB, Level = -26dBov, AMR12.2",
   "Test Condition 4b:  STREET NOISE@15dB, Level = -26dBov, AMR5.9",
   "Test Condition 10b: CAR NOISE@6dB,     Level = -36dBov, AMR12.2",
   "Test Condition 10c: CAR NOISE@6dB,     Level = -16dBov, AMR12.2"
};


/***********************************************************************/
/*             Description of each group of preprocessed files         */
/*             Last record must be set to -1 to enable detection       */
/*               of the end of the structure                           */
/***********************************************************************/

FileDesc files[] = {

/*                       -------------------------------------------------                   */
/*********************** Test Condition 1a: CAR NOISE@6dB, Level = -26dBov *******************/
/*                       -------------------------------------------------                   */
 
   /* Listening Test Experiment 3a */
   /* AMR Mode 12.2 kbps */
   /* Lab f */
   /* Condition 19 car noise 6dB */
   {
      CAR_NOISE_1a,                 /* Noise type */
      "MR122",                      /* Mode rate */
      DATABASE_ROOT,                /* Host Lab */
      "03a",                        /* Experiment */
      "f",                          /* Host acronym */
      AMRNS_CANDIDATE_ACRONYM,      /* Candidate acronym */
      "s0",                         /* Sample number begin string */
      1,                            /* First sample */
      7,                            /* Last sample */
      1,                            /* Number of digit in sample number */
      "19"                          /* Condition */
   },
   
   /* Listening Test Experiment 5a */
   /* AMR Mode 12.2 kbps */
   /* Lab c */
   /* Condition 15 car noise 6dB */
   {
      CAR_NOISE_1a,                 /* Noise type */
      "MR122",                      /* Mode rate */
      DATABASE_ROOT,                /* Host Lab */
      "05a",                        /* Experiment */
      "c",                          /* Host acronym */
      AMRNS_CANDIDATE_ACRONYM,      /* Candidate acronym */
      "s0",                         /* Sample number begin string */
      1,                            /* First sample */
      6,                            /* Last sample */
      1,                            /* Number of digit in sample number */
      "15"                          /* Condition */
   },
   {
      CAR_NOISE_1a,                 /* Noise type */
      "MR122",                      /* Mode rate */
      DATABASE_ROOT,                /* Host Lab */
      "05a",                        /* Experiment */
      "c",                          /* Host acronym */
      AMRNS_CANDIDATE_ACRONYM,      /* Candidate acronym */
      "s1",                         /* Sample number begin string */
      2,                            /* First sample */
      2,                            /* Last sample */
      1,                            /* Number of digit in sample number */
      "15"                          /* Condition */
   },

   /* Listening Test Experiment 10 */
   /* AMR Mode 12.2 kbps */
   /* Lab c */
    /* Condition 19 car noise 6dB */
  
   {
      CAR_NOISE_1a,                 /* Noise type */
     "MR122",                       /* Mode rate */
      DATABASE_ROOT,                /* Host Lab */
      "10a",                        /* Experiment */
      "c",                          /* Host acronym */
      AMRNS_CANDIDATE_ACRONYM,      /* Candidate acronym */
      "s0",                         /* Sample number begin string */
      1,                            /* First sample */
      6,                            /* Last sample */
      1,                            /* Number of digit in sample number */
      "19"                          /* Condition */
   },
   {
      CAR_NOISE_1a,                 /* Noise type */
     "MR122",                       /* Mode rate */
      DATABASE_ROOT,                /* Host Lab */
      "10a",                        /* Experiment */
      "c",                          /* Host acronym */
      AMRNS_CANDIDATE_ACRONYM,      /* Candidate acronym */
      "s1",                         /* Sample number begin string */
      3,                            /* First sample */
      3,                            /* Last sample */
      1,                            /* Number of digit in sample number */
      "19"                          /* Condition */
   },

/*                       -------------------------------------------------                   */
/*********************** Test Condition 1b: CAR NOISE@6dB, Level = -26dBov *******************/
/*                       -------------------------------------------------                   */
  
   /* Listening Test Experiment 4a */
   /* AMR Mode 5.9 kbps */
   /* Lab c */
   /* Condition 15 car noise 6dB */
   {
      CAR_NOISE_1b,                 /* Noise type */
      "MR59",                       /* Mode rate */
      DATABASE_ROOT,                /* Host Lab */
      "04a",                        /* Experiment */
      "c",                          /* Host acronym */
      AMRNS_CANDIDATE_ACRONYM,      /* Candidate acronym */
      "s0",                         /* Sample number begin string */
      1,                            /* First sample */
      6,                            /* Last sample */
      1,                            /* Number of digit in sample number */
      "15"                          /* Condition */
   },
   {
      CAR_NOISE_1b,                 /* Noise type */
      "MR59",                       /* Mode rate */
      DATABASE_ROOT,                /* Host Lab */
      "04a",                        /* Experiment */
      "c",                          /* Host acronym */
      AMRNS_CANDIDATE_ACRONYM,      /* Candidate acronym */
      "s1",                         /* Sample number begin string */
      2,                            /* First sample */
      2,                            /* Last sample */
      1,                            /* Number of digit in sample number */
      "15"                          /* Condition */
   },

/*                       -------------------------------------------------                    */
/*********************** Test Condition 2a: CAR NOISE@12dB, Level = -26dBov *******************/
/*                       -------------------------------------------------                    */
   
   /* Listening Test Experiment 5b */
   /* AMR Mode 12.2 kbps */
   /* Lab c */
   /* Condition 15 car noise 12dB */
   {
      CAR_NOISE_2a,                 /* Noise type */
     "MR122",                       /* Mode rate */
      DATABASE_ROOT,                /* Host Lab */
      "05b",                        /* Experiment */
      "c",                          /* Host acronym */
      AMRNS_CANDIDATE_ACRONYM,      /* Candidate acronym */
      "s0",                         /* Sample number begin string */
      6,                            /* First sample */
      9,                            /* Last sample */
      1,                            /* Number of digit in sample number */
      "15"                          /* Condition */
   },
   {
      CAR_NOISE_2a,                 /* Noise type */
      "MR122",                      /* Mode rate */
      DATABASE_ROOT,                /* Host Lab */
      "05b",                        /* Experiment */
      "c",                          /* Host acronym */
      AMRNS_CANDIDATE_ACRONYM,      /* Candidate acronym */
      "s1",                         /* Sample number begin string */
      0,                            /* First sample */
      2,                            /* Last sample */
      1,                            /* Number of digit in sample number */
      "15"                          /* Condition */
   },

/*                       -------------------------------------------------                    */
/*********************** Test Condition 2b: CAR NOISE@12dB, Level = -26dBov *******************/
/*                       -------------------------------------------------                    */

   /* Listening Test Experiment 4b */
   /* AMR Mode 5.9 kbps */
   /* Lab c */
   /* Condition 15 car noise 12dB */
   {
      CAR_NOISE_2b,                 /* Noise type */
      "MR59",                       /* Mode rate */
      DATABASE_ROOT,                /* Host Lab */
      "04b",                        /* Experiment */
      "c",                          /* Host acronym */
      AMRNS_CANDIDATE_ACRONYM,      /* Candidate acronym */
      "s0",                         /* Sample number begin string */
      6,                            /* First sample */
      9,                            /* Last sample */
      1,                            /* Number of digit in sample number */
      "15"                          /* Condition */
   },
   {
      CAR_NOISE_2b,                 /* Noise type */
      "MR59",                       /* Mode rate */
      DATABASE_ROOT,                /* Host Lab */
      "04b",                        /* Experiment */
      "c",                          /* Host acronym */
      AMRNS_CANDIDATE_ACRONYM,      /* Candidate acronym */
      "s1",                         /* Sample number begin string */
      0,                            /* First sample */
      2,                            /* Last sample */
      1,                            /* Number of digit in sample number */
      "15"                          /* Condition */
   },


/*                       ----------------------------------------------------                   */
/*********************** Test Condition 3a: STREET NOISE@9dB, Level = -26dBov *******************/
/*                       ----------------------------------------------------                   */
 
   /* Listening Test Experiment 3b */
   /* AMR Mode 12.2 kbps */
   /* Lab f */
   /* Condition 19 street noise 9dB */
   {
      STREET_NOISE_3a,              /* Noise type */
      "MR122",                      /* Mode rate */
      DATABASE_ROOT,                /* Host Lab */
      "03b",                        /* Experiment */
      "f",                          /* Host acronym */
      AMRNS_CANDIDATE_ACRONYM,      /* Candidate acronym */
      "s0",                         /* Sample number begin string */
      1,                            /* First sample */
      7,                            /* Last sample */
      1,                            /* Number of digit in sample number */
      "19"                          /* Condition */
   },
   
   /* Listening Test Experiment 5a */
   /* AMR Mode 12.2 kbps */
   /* Lab c */
   /* Condition 21 street noise 9dB */
   {
      STREET_NOISE_3a,              /* Noise type */
     "MR122",                       /* Mode rate */
      DATABASE_ROOT,                /* Host Lab */
      "05a",                        /* Experiment */
      "c",                          /* Host acronym */
      AMRNS_CANDIDATE_ACRONYM,      /* Candidate acronym */
      "s0",                         /* Sample number begin string */
      1,                            /* First sample */
      6,                            /* Last sample */
      1,                            /* Number of digit in sample number */
      "21"                          /* Condition */
   },
   {
      STREET_NOISE_3a,              /* Noise type */
      "MR122",                      /* Mode rate */
      DATABASE_ROOT,                /* Host Lab */
      "05a",                        /* Experiment */
      "c",                          /* Host acronym */
      AMRNS_CANDIDATE_ACRONYM,      /* Candidate acronym */
      "s1",                         /* Sample number begin string */
      2,                            /* First sample */
      2,                            /* Last sample */
      1,                            /* Number of digit in sample number */
      "21"                          /* Condition */
   },

/*                       ----------------------------------------------------                   */
/*********************** Test Condition 3b: STREET NOISE@9dB, Level = -26dBov *******************/
/*                       ----------------------------------------------------                   */

   /* Listening Test Experiment 4a */
   /* AMR Mode 5.9 kbps */
   /* Lab c */
   /* Condition 21 street noise 9dB */
   {
      STREET_NOISE_3b,              /* Noise type */
      "MR59",                       /* Mode rate */
      DATABASE_ROOT,                /* Host Lab */
      "04a",                        /* Experiment */
      "c",                          /* Host acronym */
      AMRNS_CANDIDATE_ACRONYM,      /* Candidate acronym */
      "s0",                         /* Sample number begin string */
      1,                            /* First sample */
      6,                            /* Last sample */
      1,                            /* Number of digit in sample number */
      "21"                          /* Condition */
   },
   {
      STREET_NOISE_3b,              /* Noise type */
      "MR59",                       /* Mode rate */
      DATABASE_ROOT,                /* Host Lab */
      "04a",                        /* Experiment */
      "c",                          /* Host acronym */
      AMRNS_CANDIDATE_ACRONYM,      /* Candidate acronym */
      "s1",                         /* Sample number begin string */
      2,                            /* First sample */
      2,                            /* Last sample */
      1,                            /* Number of digit in sample number */
      "21"                          /* Condition */
   },

/*                       -----------------------------------------------------                 */
/*********************** Test Condition 4a: STREET NOISE@15dB, Level = -26dBov *****************/
/*                       -----------------------------------------------------                 */
 
   /* Listening Test Experiment 5b */
   /* AMR Mode 12.2 kbps */
   /* Lab c */
   /* Condition 21 street noise 12dB */
   {
      STREET_NOISE_4a,              /* Noise type */
      "MR122",                      /* Mode rate */
      DATABASE_ROOT,                /* Host Lab */
      "05b",                        /* Experiment */
      "c",                          /* Host acronym */
      AMRNS_CANDIDATE_ACRONYM,      /* Candidate acronym */
      "s0",                         /* Sample number begin string */
      6,                            /* First sample */
      9,                            /* Last sample */
      1,                            /* Number of digit in sample number */
      "21"                          /* Condition */
   },
     {
      STREET_NOISE_4a,              /* Noise type */
      "MR122",                      /* Mode rate */
      DATABASE_ROOT,                /* Host Lab */
      "05b",                        /* Experiment */
      "c",                          /* Host acronym */
      AMRNS_CANDIDATE_ACRONYM,      /* Candidate acronym */
      "s1",                         /* Sample number begin string */
      0,                            /* First sample */
      2,                            /* Last sample */
      1,                            /* Number of digit in sample number */
      "21"                          /* Condition */
   },

/*                       -----------------------------------------------------                 */
/*********************** Test Condition 4b: STREET NOISE@15dB, Level = -26dBov *****************/
/*                       -----------------------------------------------------                 */
   /* Listening Test Experiment 4b */
   /* AMR Mode 5.9 kbps */
   /* Lab c */
   /* Condition 21 street noise 12dB */
   {
      STREET_NOISE_4b,              /* Noise type */
      "MR59",                       /* Mode rate */
      DATABASE_ROOT,                /* Host Lab */
      "04b",                        /* Experiment */
      "c",                          /* Host acronym */
      AMRNS_CANDIDATE_ACRONYM,      /* Candidate acronym */
      "s0",                         /* Sample number begin string */
      6,                            /* First sample */
      9,                            /* Last sample */
      1,                            /* Number of digit in sample number */
      "21"                          /* Condition */
   },
   {
      STREET_NOISE_4b,              /* Noise type */
      "MR59",                       /* Mode rate */
      DATABASE_ROOT,                /* Host Lab */
      "04b",                        /* Experiment */
      "c",                          /* Host acronym */
      AMRNS_CANDIDATE_ACRONYM,      /* Candidate acronym */
      "s1",                         /* Sample number begin string */
      0,                            /* First sample */
      2,                            /* Last sample */
      1,                            /* Number of digit in sample number */
      "21"                          /* Condition */
   },

/*                       --------------------------------------------------                 */
/*********************** Test Condition 10b: CAR NOISE@6dB, Level = -36dBov *****************/
/*                       --------------------------------------------------                 */

   /* Listening Test Experiment 10 */
   /* AMR Mode 12.2 kbps */
   /* Lab c */
   /* Condition 13 car noise 6dB */
   {
      CAR_NOISE_10b,                /* Noise type */
      "MR122",                      /* Mode rate */
      DATABASE_ROOT,                /* Host Lab */
      "10a",                        /* Experiment */
      "c",                          /* Host acronym */
      AMRNS_CANDIDATE_ACRONYM,      /* Candidate acronym */
      "s0",                         /* Sample number begin string */
      1,                            /* First sample */
      6,                            /* Last sample */
      1,                            /* Number of digit in sample number */
      "13"                          /* Condition */
   },
   {
      CAR_NOISE_10b,                /* Noise type */
      "MR122",                      /* Mode rate */
      DATABASE_ROOT,                /* Host Lab */
      "10a",                        /* Experiment */
      "c",                          /* Host acronym */
      AMRNS_CANDIDATE_ACRONYM,      /* Candidate acronym */
      "s1",                         /* Sample number begin string */
      3,                            /* First sample */
      3,                            /* Last sample */
      1,                            /* Number of digit in sample number */
      "13"                          /* Condition */
   },

/*                       --------------------------------------------------                 */
/*********************** Test Condition 10c: CAR NOISE@6dB, Level = -16dBov *****************/
/*                       --------------------------------------------------                 */

   /* Listening Test Experiment 10 */
   /* AMR Mode 12.2 kbps */
   /* Lab c */
   /* Condition 25 car noise 6dB */
   {
      CAR_NOISE_10c,                /* Noise type */
      "MR122",                      /* Mode rate */
      DATABASE_ROOT,                /* Host Lab */
      "10a",                        /* Experiment */
      "c",                          /* Host acronym */
      AMRNS_CANDIDATE_ACRONYM,      /* Candidate acronym */
      "s0",                         /* Sample number begin string */
      1,                            /* First sample */
      6,                            /* Last sample */
      1,                            /* Number of digit in sample number */
      "25"                          /* Condition */
   },
   {
      CAR_NOISE_10c,                /* Noise type */
      "MR122",                      /* Mode rate */
      DATABASE_ROOT,                /* Host Lab */
      "10a",                        /* Experiment */
      "c",                          /* Host acronym */
      AMRNS_CANDIDATE_ACRONYM,      /* Candidate acronym */
      "s1",                         /* Sample number begin string */
      3,                            /* First sample */
      3,                            /* Last sample */
      1,                            /* Number of digit in sample number */
      "25"                          /* Condition */
   },

/*                       ------------------------------------------------------                */
/*********************** Last element must be set at -1 to enable end detection ****************/
/*                       ------------------------------------------------------                */
   {
      -1
   }
};
